# qrcodeT
This simple library generates text-based QR codes to be used directly in the console (terminal).
## Installation
using pip:
```
pip install qrcodeT
```
or directly from here:
```
pip install git+git://github.com/Khalil-Youssefi/qrcodeT.git#egg=qrcodeT
```
## Usage
You can directly use this library to create a QR code from a text and directly print it on the console:
```
import qrcodeT
qrcodeT.qrcodeT('https://github.com/Khalil-Youssefi/qrcodeT')
```
and the output will be:

![[sample output on github page](https://github.com/Khalil-Youssefi)](./qrcodeT_sample.JPG)
